@@ -17,7 +17,7 @@
 /* #undef OGRE_BUILD_PLUGIN_GLSLANG */
 #define OGRE_BUILD_PLUGIN_STBI
 /* #undef OGRE_BUILD_PLUGIN_RSIMAGE */
-#define OGRE_BUILD_PLUGIN_FREEIMAGE
+/* #undef OGRE_BUILD_PLUGIN_FREEIMAGE */
 #define OGRE_BUILD_PLUGIN_DOT_SCENE
 #define OGRE_BUILD_COMPONENT_PAGING
 #define OGRE_BUILD_COMPONENT_MESHLODGENERATOR
